@@ -233,6 +233,16 @@ export default class Reporter {
 				break;
 			}
 
+			case 'process-exit': {
+				this.write(colors.error(`${figures.cross} Exiting due to process.exit() when running ${this.relativeFile(event.testFile)}`));
+
+				this.lineWriter.writeLine();
+				this.lineWriter.writeLine(colors.errorStack(event.stack));
+				this.lineWriter.writeLine();
+
+				break;
+			}
+
 			case 'hook-finished': {
 				if (event.logs.length > 0) {
 					this.lineWriter.writeLine(`  ${this.prefixTitle(event.testFile, event.title)}`);
@@ -244,9 +254,9 @@ export default class Reporter {
 
 			case 'selected-test': {
 				if (event.skip) {
-					this.lineWriter.writeLine(colors.skip(`- ${this.prefixTitle(event.testFile, event.title)}`));
+					this.lineWriter.writeLine(colors.skip(`- [skip] ${this.prefixTitle(event.testFile, event.title)}`));
 				} else if (event.todo) {
-					this.lineWriter.writeLine(colors.todo(`- ${this.prefixTitle(event.testFile, event.title)}`));
+					this.lineWriter.writeLine(colors.todo(`- [todo] ${this.prefixTitle(event.testFile, event.title)}`));
 				}
 
 				break;
@@ -504,15 +514,30 @@ export default class Reporter {
 	}
 
 	writeTestSummary(event) {
+		// Prefix icon indicates matched expectations vs. not.
+		// Prefix color indicates passed-as-expected vs. not (fail or unexpected pass).
+		// This yields four possibilities, which in the standard configuration render as:
+		// * normal test, pass:        <green>✔</green>
+		// * normal test, fail:          <red>✘ [fail]</red>
+		// * fail-expected test, fail:   <red>✔ [expected fail]</red>
+		// * fail-expected test, pass:   <red>✘ [unexpected pass]</red>
+		let prefix;
+		let suffix;
 		if (event.type === 'hook-failed' || event.type === 'test-failed') {
-			this.write(`${colors.error(figures.cross)} ${this.prefixTitle(event.testFile, event.title)} ${colors.error(event.err.message)}`);
+			const type = event.knownFailing ? '[unexpected pass]' : '[fail]';
+			prefix = colors.error(`${figures.cross} ${type}:`);
+			suffix = chalk.italic(colors.error(event.err.message));
 		} else if (event.knownFailing) {
-			this.write(`${colors.error(figures.tick)} ${colors.error(this.prefixTitle(event.testFile, event.title))}`);
+			prefix = colors.error(figures.tick + ' [expected fail]');
 		} else {
-			const duration = event.duration > this.durationThreshold ? colors.duration(' (' + prettyMs(event.duration) + ')') : '';
-			this.write(`${colors.pass(figures.tick)} ${this.prefixTitle(event.testFile, event.title)}${duration}`);
+			prefix = colors.pass(figures.tick);
+			if (event.duration > this.durationThreshold) {
+				suffix = colors.duration(`(${prettyMs(event.duration)})`);
+			}
 		}
 
+		const label = this.prefixTitle(event.testFile, event.title);
+		this.write(`${prefix} ${label}${suffix ? ' ' + suffix : ''}`);
 		this.writeLogs(event);
 	}
 
@@ -658,8 +683,8 @@ export default class Reporter {
 			this.lineWriter.writeLine(colors.error(`${this.stats.uncaughtExceptions} uncaught ${plur('exception', this.stats.uncaughtExceptions)}`));
 		}
 
-		if (this.stats.timeouts > 0) {
-			this.lineWriter.writeLine(colors.error(`${this.stats.timeouts} ${plur('test', this.stats.timeouts)} remained pending after a timeout`));
+		if (this.stats.timedOutTests > 0) {
+			this.lineWriter.writeLine(colors.error(`${this.stats.timedOutTests} ${plur('test', this.stats.timedOutTests)} remained pending after a timeout`));
 		}
 
 		if (this.previousFailures > 0) {
